#!/bin/bash
# Ce script permet de creer des machines virtuelles permettant de simuler
# un reseau complet. Les machines sont copiees depuis le repertoire vdi
# vers le repertoire travail et prefixées du nom de l'utilisateur.

#La quantite de memoire allouee a chaque machine
MEMORY=128
#Virtualisation hardware VT-X (on ou off)
HWVIRTEX=on

#--------------- DEBUT DES PARAMETRES ----------------
setParametres() {
## Decommenter seulement les deux lignes suivantes en salle de TP pour une utilisation multiutilisateurs
vdipath=/usr/local/vbox/travail
vdiname=${vdipath}/$USER-${machinename}.vdi

## Decommenter les deux lignes suivantes pour une installation linux standard
#vdipath=~/.VirtualBox/HardDisks/
#vdiname=${vdipath}/${machinename}.vdi

## Decommenter les deux lignes suivantes et adapter si les .vdi sont dans un autre dossier
#vdipath=/usr/local/data/virtualbox/HardDisks/
#vdiname=${vdipath}/${machinename}.vdi

}
#--------------- FIN DES PARAMETRES ----------------

setVMparameters() {
memory=$1
macaddress1=$2
nic1=$3
if [ "$4" != "-" ]; then
intnet1="--intnet1 "$4
else
intnet1=""
fi
if [ "$5" != "-" ]; then
macaddress2=$5
else 
macaddress2=""
fi
if [ "$6" != "-" ]; then
nic2=$6
else 
nic2=""
fi
if [ "$7" != "-" ]; then
intnet2="--intnet2 "$7
else
intnet2=""
fi
macaddress3=$8

echo "-- Creating  IDE Controller-"${machinename}
VBoxManage -q  storagectl ${machinename} --name "IDE Controller-"${machinename}\
 --add ide 
echo "-- Attaching "${vdiname}" to IDE Controller-"${machinename}
VBoxManage -q  storageattach ${machinename}\
 --storagectl "IDE Controller-"${machinename}\
 --port 0 --device 0 --type hdd --medium ${vdiname}

echo "-- Setting specific parameters for "${machinename}
VBoxManage -q  modifyvm ${machinename} --memory ${memory} --vram 1 --hwvirtex ${HWVIRTEX} \
--boot1 disk --ostype Debian 

# Configuration de la carte reseau 1
if [ -n "${macaddress1}" ]; then
VBoxManage -q  modifyvm ${machinename} --macaddress1 ${macaddress1} --nic1 ${nic1} ${intnet1} \
--cableconnected1 on
fi

# Configuration de la carte reseau 2 si necessaire
if [ -n "${macaddress2}" ]; then
VBoxManage -q  modifyvm ${machinename} --macaddress2 ${macaddress2} --nic2 ${nic2} ${intnet2} \
--cableconnected2 on
fi

# TOUTES les machines ont une carte reseau connectée directement à l'hote (cf. wireshark)
VBoxManage -q  modifyvm ${machinename} --macaddress3 ${macaddress3} --nic3 hostonly --hostonlyadapter3 vboxnet0 \
--cableconnected3 on
}

if [ "$#" -lt "2" ]; then
        echo "usage : $0 [clonemaster|create|run|halt|remove|info] all|[clientlinux|firewalllocal|serveurlinux\
|firewallinternet]+"
	exit 1;
fi

i=0
if [ "$2" = "all" ]; then
    machines="firewallinternet firewalllocal serveurlinux clientlinux"
else
    machines=""
    for machinename in $@ 
    do
	i=$(( $i + 1 ))
	if [ $i -gt 1 ]; then 
	    machines="${machines} ${machinename}"
	fi
    done
fi

for machinename in ${machines};
do

setParametres
echo "### $1 ${machinename} ${vdipath} ${vdiname} ###"
if [ "$1" = "info" ]; then
VBoxManage showvminfo ${machinename}|grep -e ^NIC -e ^IDE -e ^Name -e ^Memory|grep -v disabled|sed 's/Name/\nName/'
fi
		
if [ "$1" = "clonemaster" ]; then
### cloner le disque virtuel de base :
VBoxManage -q  clonevdi ${machinename}.vdi\
 ${vdiname}
fi

if [ "$1" = "remove" ]; then
### Remove machine
VBoxManage -q  storageattach ${machinename}\
 --storagectl "IDE Controller-"${machinename}\
 --port 0 --device 0 --type hdd --medium none
VBoxManage -q  storagectl ${machinename} --name "IDE Controller-"${machinename}\
 --remove
VBoxManage -q  unregistervm ${machinename} --delete
VBoxManage -q  unregisterimage disk ${vdiname}

fi

if [ "$1" = "create" ]; then
### signaler à VBox qu'il peut utiliser ce disque :
echo "-- Registering disk "${vdiname}
VBoxManage -q  registerimage disk ${vdiname}

### créer la machine virtuelle :
echo "-- Creating VM "${machinename}
VBoxManage -q  createvm --name ${machinename} --register 

### donner ses caractéristiques à cette machine :
memory=${MEMORY}
case $machinename in
clientlinux )
macaddress1=08002763163A
nic1=intnet
intnet1=local_net
macaddress2="-"
nic2="-"
intnet2="-"
macaddress3=080027938931
;;

firewalllocal )
macaddress1=080027A8F55F
nic1=intnet
intnet1=local_net
macaddress2=0800277F3AC0
nic2=intnet
intnet2=dmz_net
macaddress3=080027461379
;;

serveurlinux )
macaddress1=08002752F728
nic1=intnet
intnet1=dmz_net
macaddress2="-"
nic2="-"
intnet2="-"
macaddress3=080027CA616C
;;

firewallinternet )
macaddress1=080027D346C9
nic1=intnet
intnet1=dmz_net
macaddress2=0800274D1FD5
nic2=nat
intnet2="-"
macaddress3=080027D6A3BE
;;

esac
setVMparameters ${memory} ${macaddress1} ${nic1} ${intnet1} ${macaddress2} ${nic2} ${intnet2} ${macaddress3}
fi

if [ "$1" = "run" ]; then
### Il ne reste plus qu'à démarrer la machine virtuelle :
VBoxManage -q  startvm ${machinename}
sleep 5
fi

if [ "$1" = "halt" ]; then
VBoxManage -q controlvm  ${machinename} acpipowerbutton
fi

done